@@ -140,12 +140,18 @@ class DjangoClient(Client):
         install_sql_hook()
 
     def get_user_info(self, user):
-        if hasattr(user, 'is_authenticated') and \
-           not user.is_authenticated():
-            return None
-
-        user_info = {}
         try:
+            if hasattr(user, 'is_authenticated'):
+                # is_authenticated was a method in Django < 1.10
+                if callable(user.is_authenticated):
+                    authenticated = user.is_authenticated()
+                else:
+                    authenticated = user.is_authenticated
+                if not authenticated:
+                    return None
+
+            user_info = {}
+
             user_info['id'] = user.pk
 
             if hasattr(user, 'email'):
@@ -282,7 +288,7 @@ class DjangoClient(Client):
             # attach the sentry object to the request
             request.sentry = {
                 'project_id': data.get('project', self.remote.project),
-                'id': self.get_ident(result),
+                'id': result,
             }
 
         return result
